package fr.openium.consentium_ui.domain.repository

import fr.openium.consentium.domain.useCase.GetAuthTokenUseCase
import fr.openium.consentium_ui.data.remote.ConsentiumUIApi
import fr.openium.consentium_ui.domain.adapter.toConsentConfigData
import fr.openium.consentium_ui.domain.model.ContentConfigData
import timber.log.Timber
import javax.inject.Inject

internal class ConsentiumRepository @Inject constructor(
    private val consentiumUIApi: ConsentiumUIApi,
    private val getAuthTokenUseCase: GetAuthTokenUseCase,
) {
    suspend fun getConsentiumConfig(
        applicationId: String,
        apiKey: String,
    ): ConsentiumUIRepositoryResponse {
        return try {
            val authToken = getAuthTokenUseCase(apiKey)
            val consentsResponse = consentiumUIApi.getConsentConfig(authToken, applicationId)
            val consentsBody = if (consentsResponse.isSuccessful) {
                consentsResponse.body() ?: throw Exception()
            } else {
                throw Exception()
            }

            ConsentiumUIRepositoryResponse.Success(consentsBody.toConsentConfigData())
        } catch (e: Exception) {
            Timber.d("$e")
            ConsentiumUIRepositoryResponse.Error
        }
    }
}

internal interface ConsentiumUIRepositoryResponse {

    data object Error : ConsentiumUIRepositoryResponse

    data class Success(val contentConfigData: ContentConfigData) : ConsentiumUIRepositoryResponse

}