package fr.openium.consentium_ui.ui.components

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.heightIn
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import coil3.compose.AsyncImage
import fr.openium.consentium_ui.R
import fr.openium.consentium_ui.ui.components.core.TextLink
import fr.openium.consentium_ui.ui.components.core.button.ConsentButton
import fr.openium.consentium_ui.ui.components.core.button.ConsentiumUIButtonStyle
import fr.openium.consentium_ui.ui.components.style.ConsentiumUITheme
import fr.openium.consentium_ui.ui.model.GeneralConsentUI
import fr.openium.consentium_ui.ui.model.LoadingElement
import fr.openium.consentium_ui.ui.utils.toRichHtmlString

@Composable
internal fun ConsentiumUIGeneralConsentComponent(
    generalConsentUI: GeneralConsentUI,
    loadingElement: LoadingElement,
    onClickCookiesPolicies: () -> Unit,
    onDenyAndClose: () -> Unit,
    onAcceptAndClose: () -> Unit,
    onNavigateToDetails: () -> Unit,
) {
    // View
    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(horizontal = 24.dp),
    ) {
        if (generalConsentUI.iconUrl != null) {
            Row(
                modifier = Modifier.fillMaxWidth(),
                horizontalArrangement = Arrangement.Center,
            ) {
                AsyncImage(
                    modifier = Modifier.heightIn(min = 48.dp),
                    model = generalConsentUI.iconUrl,
                    contentDescription = stringResource(R.string.app_icon),
                    contentScale = ContentScale.FillBounds,
                )
            }

            Spacer(modifier = Modifier.height(24.dp))
        }

        Text(
            text = generalConsentUI.mainConsentText.toRichHtmlString(),
            style = ConsentiumUITheme.typography.p3,
            textAlign = TextAlign.Start,
            color = ConsentiumUITheme.colors.onSurface,
            overflow = TextOverflow.Ellipsis,
        )

        Spacer(modifier = Modifier.height(16.dp))

        TextLink(
            text = stringResource(R.string.cookies),
            onclick = onClickCookiesPolicies,
        )

        Spacer(modifier = Modifier
            .heightIn(16.dp)
            .weight(1f))

        TextLink(
            text = stringResource(R.string.refuse),
            onclick = onDenyAndClose,
            isLoading = loadingElement == LoadingElement.LINK,
        )

        Spacer(modifier = Modifier.height(16.dp))

        ConsentButton(
            text = stringResource(R.string.accept),
            buttonStyle = ConsentiumUIButtonStyle.PRIMARY,
            onclick = onAcceptAndClose,
            isLoading = loadingElement == LoadingElement.BUTTON,
        )

        Spacer(modifier = Modifier.height(16.dp))

        ConsentButton(
            text = stringResource(R.string.parameters),
            buttonStyle = ConsentiumUIButtonStyle.SECONDARY,
            onclick = onNavigateToDetails,
        )

        Spacer(modifier = Modifier.height(10.dp))
    }
}

@Preview(showSystemUi = true)
@Composable
private fun ConsentiumUIGeneralConsentComponentPreview() {
    ConsentiumUIGeneralConsentComponent(
        generalConsentUI = GeneralConsentUI(
            iconUrl = "https://amp.openium.fr/openium.png",
            mainConsentText = "[Nom de l’application] utilise des cookies pour différents objectifs : faire fonctionner l’application, améliorer nos services en mesurant l’efficacité de nos contenus et afficher des publicités susceptibles de vous intéresser. \n\n En cliquant sur “Accepter et fermer”, vous acceptez cette utilisation sur l’application mobile. Vous pouvez également paramétrer vos choix en cliquant sur “Paramétrer mes choix” ou refuser ces cookies en cliquant sur “Continuer sans accepter”. Vous pouvez changer d’avis à tout moment depuis les paramètres de votre compte via l’onglet “Notifications et cookies”.",
            applicationName = "Application name",
            consentPageUrl = "https://www.google.com"
        ),
        onClickCookiesPolicies = {},
        onDenyAndClose = {},
        onAcceptAndClose = {},
        onNavigateToDetails = {},
        loadingElement = LoadingElement.LINK,
    )
}