package fr.openium.consentium_ui.ui.components.core.button

import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import fr.openium.consentium_ui.ui.components.style.ConsentiumUITheme

@Composable
internal fun ConsentButton(
    text: String,
    buttonStyle: ConsentiumUIButtonStyle,
    onclick: () -> Unit,
    isLoading: Boolean = false,
) {
    Button(
        onClick = onclick,
        modifier = Modifier
            .fillMaxWidth()
            .height(40.dp),
        shape = RoundedCornerShape(6.dp),
        colors = ButtonDefaults.buttonColors(buttonStyle.backgroundColor())
    ) {
        if (isLoading) {
            CircularProgressIndicator(
                modifier = Modifier.size(24.dp),
                color = ConsentiumUITheme.colors.onPrimary,
            )
        } else {
            Text(
                text = text,
                color = ConsentiumUITheme.colors.onPrimary,
                style = ConsentiumUITheme.typography.button,
            )
        }
    }
}

@Preview
@Composable
private fun ConsentButtonPreview() {
    ConsentButton(
        text = "Accept and close",
        buttonStyle = ConsentiumUIButtonStyle.PRIMARY,
        onclick = {}
    )
}